==> NetteFramework-2.0.1-PHP5.2-nonprefix.zip: NetteFramework-2.0.1-PHP5.2-nonprefix/sandbox/libs/Nette/loader.php <==
<?php

/**
 * Nette Framework (version 2.0.1 released on 2012-02-29, http://nette.org)
 *
 * Copyright (c) 2004, 2012 David Grudl (http://davidgrudl.com)
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 */



/**
 * Check and reset PHP configuration.
 */
if (!defined('PHP_VERSION_ID')) {
	$tmp = explode('.', PHP_VERSION);
	define('PHP_VERSION_ID', ($tmp[0] * 10000 + $tmp[1] * 100 + $tmp[2]));
}

if (PHP_VERSION_ID < 50200) {
	throw new Exception('Nette Framework requires PHP 5.2.0 or newer.');
}

error_reporting(E_ALL | E_STRICT);
@set_magic_quotes_runtime(FALSE); // @ - deprecated since PHP 5.3.0
iconv_set_encoding('internal_encoding', 'UTF-8');
extension_loaded('mbstring') && mb_internal_encoding('UTF-8');
umask(0);
@header('X-Powered-By: Nette Framework'); // @ - headers may be sent
@header('Content-Type: text/html; charset=utf-8'); // @ - headers may be sent



/**
 * Load and configure Nette Framework.
 */

/** @internal */
class NCFix
{
	static $vars = array();

	static function uses($args)
	{
		self::$vars[] = $args;
		return count(self::$vars)-1;
	}
}

define('NETTE', TRUE);
define('NETTE_DIR', dirname(__FILE__));
define('NETTE_VERSION_ID', 20001); // v2.0.1
define('NETTE_PACKAGE', 'PHP 5.2');



require_once dirname(__FILE__) . '/common/exceptions.php';
require_once dirname(__FILE__) . '/common/Object.php';
require_once dirname(__FILE__) . '/Utils/LimitedScope.php';
require_once dirname(__FILE__) . '/Loaders/AutoLoader.php';
require_once dirname(__FILE__) . '/Loaders/NetteLoader.php';


NetteLoader::getInstance()->register();

require_once dirname(__FILE__) . '/Diagnostics/Helpers.php';
require_once dirname(__FILE__) . '/Diagnostics/shortcuts.php';
require_once dirname(__FILE__) . '/Utils/Html.php';
Debugger::_init();

SafeStream::register();



/**
 * Callback factory.
 * @param  mixed   class, object, function, callback
 * @param  string  method
 * @return Callback
 */
function callback($callback, $m = NULL)
{
	return ($m === NULL && $callback instanceof Callback) ? $callback : new Callback($callback, $m);
}

==> NetteFramework-2.0.3-PHP5.2-nonprefix.zip: NetteFramework-2.0.3-PHP5.2-nonprefix/sandbox/libs/Nette/loader.php <==
<?php

/**
 * Nette Framework (version 2.0.3 released on 2012-04-04, http://nette.org)
 *
 * Copyright (c) 2004, 2012 David Grudl (http://davidgrudl.com)
 *
 * For the full copyright and license information, please view
 * the file license.txt that was distributed with this source code.
 */



/**
 * Check and reset PHP configuration.
 */
if (!defined('PHP_VERSION_ID')) {
	$tmp = explode('.', PHP_VERSION);
	define('PHP_VERSION_ID', ($tmp[0] * 10000 + $tmp[1] * 100 + $tmp[2]));
}

if (PHP_VERSION_ID < 50200) {
	throw new Exception('Nette Framework requires PHP 5.2.0 or newer.');
}

error_reporting(E_ALL | E_STRICT);
@set_magic_quotes_runtime(FALSE); // @ - deprecated since PHP 5.3.0
iconv_set_encoding('internal_encoding', 'UTF-8');
extension_loaded('mbstring') && mb_internal_encoding('UTF-8');
umask(0);
@header('X-Powered-By: Nette Framework'); // @ - headers may be sent
@header('Content-Type: text/html; charset=utf-8'); // @ - headers may be sent



/**
 * Load and configure Nette Framework.
 */

/** @internal */
class NCFix
{
	static $vars = array();

	static function uses($args)
	{
		self::$vars[] = $args;
		return count(self::$vars)-1;
	}
}

define('NETTE', TRUE);
define('NETTE_DIR', dirname(__FILE__));
define('NETTE_VERSION_ID', 20003); // v2.0.3
define('NETTE_PACKAGE', 'PHP 5.2');



require_once dirname(__FILE__) . '/common/exceptions.php';
require_once dirname(__FILE__) . '/common/Object.php';
require_once dirname(__FILE__) . '/Utils/LimitedScope.php';
require_once dirname(__FILE__) . '/Loaders/AutoLoader.php';
require_once dirname(__FILE__) . '/Loaders/NetteLoader.php';


NetteLoader::getInstance()->register();

require_once dirname(__FILE__) . '/Diagnostics/Helpers.php';
require_once dirname(__FILE__) . '/Diagnostics/shortcuts.php';
require_once dirname(__FILE__) . '/Utils/Html.php';
Debugger::_init();

SafeStream::register();



/**
 * Callback factory.
 * @param  mixed   class, object, callable
 * @param  string  method
 * @return Callback
 */
function callback($callback, $m = NULL)
{
	if ($m === NULL) {
		return $callback instanceof Callback ? $callback : new Callback($callback);
	}
	return new Callback(array($callback, $m));
}
